=== modified file 'cmake/modules/autopilot.cmake'
--- cmake/modules/autopilot.cmake	2014-01-09 10:53:29 +0000
+++ cmake/modules/autopilot.cmake	2014-02-22 00:12:49 +0000
@@ -2,7 +2,7 @@
 
 function(declare_autopilot_test TEST_NAME TEST_SUITE WORKING_DIR)
     add_custom_target(autopilot-${TEST_NAME}
-        COMMAND LANG=C UBUNTU_ICON_THEME=ubuntu-mobile QML2_IMPORT_PATH=${SHELL_INSTALL_QML}/mocks autopilot run ${TEST_SUITE}
+        COMMAND LANG=C UBUNTU_ICON_THEME=ubuntu-mobile QML2_IMPORT_PATH=${SHELL_INSTALL_QML}/mocks python3 -m autopilot.run run ${TEST_SUITE}
         WORKING_DIRECTORY ${WORKING_DIR}
         DEPENDS fake_install
     )
@@ -12,4 +12,13 @@
     )
 
     add_dependencies(autopilot autopilot-${TEST_NAME})
+
+    add_custom_target(autopilot2-${TEST_NAME}
+        COMMAND LANG=C UBUNTU_ICON_THEME=ubuntu-mobile QML2_IMPORT_PATH=${SHELL_INSTALL_QML}/mocks python2 -m autopilot.run run ${TEST_SUITE}
+        WORKING_DIRECTORY ${WORKING_DIR}
+        DEPENDS fake_install
+    )
+
+    add_dependencies(autopilot autopilot2-${TEST_NAME})
+
 endfunction()

=== modified file 'debian/control'
--- debian/control	2014-02-07 05:41:41 +0000
+++ debian/control	2014-02-22 00:12:49 +0000
@@ -29,6 +29,7 @@
                python:any (>= 2.7),
                python-setuptools,
                python3:any,
+               python3-setuptools,
                qt5-default,
                qtbase5-dev,
                qtbase5-dev-tools,
@@ -111,12 +112,16 @@
          python-fixtures,
          python-gi,
          python-mock,
+         python3-evdev,
+         python3-fixtures,
+         python3-gi,
          ubuntu-ui-toolkit-autopilot,
          unity8 (>= ${source:Version}),
          unity8-fake-env (>= ${source:Version}),
          url-dispatcher-tools,
          ${misc:Depends},
          ${python:Depends},
+         ${python3:Depends},
          ${shlibs:Depends},
 Description: Test package for Unity 8 shell
  Autopilot tests for the unity8 package

=== modified file 'debian/rules'
--- debian/rules	2014-01-31 09:27:25 +0000
+++ debian/rules	2014-02-22 00:12:49 +0000
@@ -10,7 +10,7 @@
 
 .PHONY: build
 build %:
-	dh $@ --parallel --fail-missing --with python2
+	dh $@ --parallel --fail-missing --with python2,python3
 
 override_dh_auto_clean:
 	dh_auto_clean
@@ -28,7 +28,7 @@
 override_dh_install:
 	# install autopilot tests
 	cd tests/autopilot; \
-	set -ex; for python in $(shell pyversions -r); do \
+	set -ex; for python in $(shell pyversions -r) $(shell py3versions -r); do \
 	    $$python setup.py install --root=$(CURDIR)/debian/tmp --install-layout=deb; \
 	done; \
 	cd $(CURDIR)

=== modified file 'tests/autopilot/unity8/__init__.py'
--- tests/autopilot/unity8/__init__.py	2014-02-06 16:06:17 +0000
+++ tests/autopilot/unity8/__init__.py	2014-02-22 00:12:49 +0000
@@ -82,7 +82,10 @@
     )
     if not os.path.exists(binary_path):
         try:
-            binary_path = subprocess.check_output(['which', binary]).strip()
+            binary_path = subprocess.check_output(
+                ['which', binary],
+                universal_newlines=True,
+            ).strip()
         except subprocess.CalledProcessError as e:
             raise RuntimeError("Unable to locate %s binary: %r" % (binary, e))
     return binary_path

=== modified file 'tests/autopilot/unity8/shell/tests/__init__.py'
--- tests/autopilot/unity8/shell/tests/__init__.py	2014-02-06 21:58:49 +0000
+++ tests/autopilot/unity8/shell/tests/__init__.py	2014-02-22 00:12:49 +0000
@@ -85,12 +85,12 @@
     @classmethod
     def setUpClass(cls):
         try:
-            output = subprocess.check_output([
-                "/sbin/initctl",
-                "status",
-                "unity8"
-            ], stderr=subprocess.STDOUT)
-        except subprocess.CalledProcessError, e:
+            output = subprocess.check_output(
+                ["/sbin/initctl", "status", "unity8"],
+                stderr=subprocess.STDOUT,
+                universal_newlines=True,
+            )
+        except subprocess.CalledProcessError as e:
             sys.stderr.write(
                 "Error: `initctl status unity8` failed, most probably the "
                 "unity8 session could not be found:\n\n"
@@ -218,12 +218,11 @@
     def _patch_environment(self, key, value):
         """Wrapper for patching env for upstart environment."""
         try:
-            current_value = subprocess.check_output([
-                "/sbin/initctl",
-                "get-env",
-                "--global",
-                key
-            ], stderr=subprocess.STDOUT).rstrip()
+            current_value = subprocess.check_output(
+                ["/sbin/initctl", "get-env", "--global", key],
+                stderr=subprocess.STDOUT,
+                universal_newlines=True,
+            ).rstrip()
         except subprocess.CalledProcessError:
             current_value = None
 
@@ -305,7 +304,7 @@
 
         binary_arg = "BINARY=%s" % binary_path
         extra_args = "ARGS=%s" % " ".join(args)
-        env_args = ["%s=%s" % (k, v) for k, v in self._environment.iteritems()]
+        env_args = ["%s=%s" % (k, v) for k, v in self._environment.items()]
         all_args = [binary_arg, extra_args] + env_args
 
         self.addCleanup(self._cleanup_launching_upstart_unity)

=== modified file 'tests/autopilot/unity8/shell/tests/test_emulators.py'
--- tests/autopilot/unity8/shell/tests/test_emulators.py	2014-01-23 06:54:39 +0000
+++ tests/autopilot/unity8/shell/tests/test_emulators.py	2014-02-22 00:12:49 +0000
@@ -27,7 +27,10 @@
 
 """
 
-import mock
+try:
+    from unittest import mock
+except ImportError:
+    import mock
 
 from testtools.matchers import Contains, HasLength
 

=== modified file 'tests/autopilot/unity8/shell/tests/test_lock_screen.py'
--- tests/autopilot/unity8/shell/tests/test_lock_screen.py	2013-12-16 22:51:30 +0000
+++ tests/autopilot/unity8/shell/tests/test_lock_screen.py	2014-02-22 00:12:49 +0000
@@ -26,12 +26,18 @@
 
 from autopilot.matchers import Eventually
 from autopilot.platform import model
+import sys
 from testtools import skipUnless
 from testtools.matchers import Equals
 import logging
 
 logger = logging.getLogger(__name__)
 
+# py2 compatible alias for py3
+if sys.version >= '3':
+    basestring = str
+
+
 class TestLockscreen(UnityTestCase):
 
     """Tests for the lock screen."""
@@ -125,7 +131,10 @@
         """
 
         if not isinstance(code, basestring):
-            raise TypeError("'code' parameter must be a string.")
+            raise TypeError(
+                "'code' parameter must be a string, not %r."
+                % type(passphrase)
+            )
         for num in code:
             if not num.isdigit():
                 raise ValueError(
@@ -142,7 +151,10 @@
 
         """
         if not isinstance(passphrase, basestring):
-            raise TypeError("'passphrase' parameter must be a string.")
+            raise TypeError(
+                "'passphrase' parameter must be a string, not %r."
+                % type(passphrase)
+            )
 
         pinentryField = self.main_window.get_pinentryField()
         self.touch.tap_object(pinentryField)
@@ -161,7 +173,10 @@
 
         """
         if not isinstance(passphrase, basestring):
-            raise TypeError("'passphrase' parameter must be a string.")
+            raise TypeError(
+                "'passphrase' parameter must be a string, not %r."
+                % type(passphrase)
+            )
 
         prompt = self.main_window.get_greeter().get_prompt()
         self.touch.tap_object(prompt)

=== modified file 'tests/autopilot/unity8/shell/tests/test_notifications.py'
--- tests/autopilot/unity8/shell/tests/test_notifications.py	2014-02-05 19:14:49 +0000
+++ tests/autopilot/unity8/shell/tests/test_notifications.py	2014-02-22 00:12:49 +0000
@@ -33,9 +33,14 @@
 import logging
 import signal
 import subprocess
+import sys
 
 logger = logging.getLogger(__name__)
 
+# backwards compatible alias for Python 3
+if sys.version > '3':
+    xrange = range
+
 
 class NotificationsBase(UnityTestCase):
     """Base class for all notification tests that provides helper methods."""
@@ -261,6 +266,7 @@
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             close_fds=True,
+            universal_newlines=True,
         )
 
         self.addCleanup(self._tidy_up_script_process)

